# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

* [`classification`](#classification): Determine group, function, etc. for classification based on certname.

### Functions

* [`classification::parse_cert_info`](#classificationparse_cert_info): Parse the cert name to determine what values to compare against.
* [`classification::parse_hostname`](#classificationparse_hostname): Parse a hostname into a hash of its parts.
* [`classification::split_hostname`](#classificationsplit_hostname): Split a hostname into its consituent parts.
* [`classification::test_fact_difference_array`](#classificationtest_fact_difference_array): If the list of differences has any values fail the run and list the issues.
* [`classification::validate_facts`](#classificationvalidate_facts): Validate a hash of facts against trusted values calculated from the certname.

## Classes

### <a name="classification"></a>`classification`

Determine group, function, etc. for classification based on certname.
This verifies that untrusted facts match the trusted values found here to
prevent attacks via fact overrides. Note that incorrect facts can still be
associated with a node since facts are sent before compilation.

This uses the same underlying code as the classification fact:
   `lib/ploperations/classification.rb`

#### Examples

##### Automatically include on every node

```puppet
# in site.pp:
include classification
```

## Functions

### <a name="classificationparse_cert_info"></a>`classification::parse_cert_info`

Type: Puppet Language

Parse the cert name to determine what values to compare against.

#### Examples

##### 

```puppet
classification::parse_cert_info($trusted['certname'])
```

#### `classification::parse_cert_info(String $trusted_cert_name)`

Parse the cert name to determine what values to compare against.

Returns: `Hash` Returns a hash containing certname, cert_hostname, and cert_domain.

##### Examples

###### 

```puppet
classification::parse_cert_info($trusted['certname'])
```

##### `trusted_cert_name`

Data type: `String`

The value of $trusted['certname'] to be parsed

### <a name="classificationparse_hostname"></a>`classification::parse_hostname`

Type: Ruby 4.x API

Parse a hostname into a hash of its parts

#### Examples

##### 

```puppet
{
  hostname      => $hostname,
  parts         => [$group, $function, $number_string, $context, $stage, $id],
  group         => $group,
  function      => $function,
  number        => $number_as_int,
  number_string => $number_string,
  context       => $context,
  stage         => $stage,
  id            => $id,
}
```

#### `classification::parse_hostname(String $hostname_string)`

Parse a hostname into a hash of its parts

Returns: `Hash` Some or all the values may be nil.

##### Examples

###### 

```puppet
{
  hostname      => $hostname,
  parts         => [$group, $function, $number_string, $context, $stage, $id],
  group         => $group,
  function      => $function,
  number        => $number_as_int,
  number_string => $number_string,
  context       => $context,
  stage         => $stage,
  id            => $id,
}
```

##### `hostname_string`

Data type: `String`

A hostname to parse

### <a name="classificationsplit_hostname"></a>`classification::split_hostname`

Type: Ruby 4.x API

Split a hostname into its consituent parts

#### Examples

##### 

```puppet
[ $group, $function, $number_string, $context, $stage, $id ]
```

#### `classification::split_hostname(String $hostname_string)`

Split a hostname into its consituent parts

Returns: `Array` Returns a 6 element array. Some or all the elements may be nil.

##### Examples

###### 

```puppet
[ $group, $function, $number_string, $context, $stage, $id ]
```

##### `hostname_string`

Data type: `String`

A hostname to parse

### <a name="classificationtest_fact_difference_array"></a>`classification::test_fact_difference_array`

Type: Puppet Language

If the list of differences has any values fail the run and list the issues.

#### Examples

##### 

```puppet
$fact_differences = $root_level_fact_differences + $classification_fact_differences
classification::test_fact_difference_array($fact_differences)
```

#### `classification::test_fact_difference_array(Array $fact_differences)`

If the list of differences has any values fail the run and list the issues.

Returns: `Boolean`

##### Examples

###### 

```puppet
$fact_differences = $root_level_fact_differences + $classification_fact_differences
classification::test_fact_difference_array($fact_differences)
```

##### `fact_differences`

Data type: `Array`

An array of strings.
These strings are generated by `classification::validate_facts`

### <a name="classificationvalidate_facts"></a>`classification::validate_facts`

Type: Puppet Language

Validate a hash of facts against trusted values calculated from the certname.

#### Examples

##### 

```puppet
$classification_calculated_trusted = $parsed_classification + {
  hostname => $hostname,
}

$classification_facts_to_validate = [
  'hostname',
  'version',
  'group',
  'function',
  'number',
  'number_string',
  'context',
  'stage',
]

$classification_fact_differences = classification::validate_facts(
  $facts['classification'],
  $classification_calculated_trusted,
  $classification_facts_to_validate,
)
```

#### `classification::validate_facts(Hash $untrusted_facts, Hash $calculated_facts, Array $fact_names)`

Validate a hash of facts against trusted values calculated from the certname.

Returns: `Array` An array of strings documenting any facts that don't match their trusted values

##### Examples

###### 

```puppet
$classification_calculated_trusted = $parsed_classification + {
  hostname => $hostname,
}

$classification_facts_to_validate = [
  'hostname',
  'version',
  'group',
  'function',
  'number',
  'number_string',
  'context',
  'stage',
]

$classification_fact_differences = classification::validate_facts(
  $facts['classification'],
  $classification_calculated_trusted,
  $classification_facts_to_validate,
)
```

##### `untrusted_facts`

Data type: `Hash`

A hash of untrusted facts

##### `calculated_facts`

Data type: `Hash`

A hash of trusted facts

##### `fact_names`

Data type: `Array`

An array of fact names to validate

